"use server";
import { Auth, raw, skipCSRFCheck } from "@auth/core";
import { headers as nextHeaders, cookies } from "next/headers";
import { redirect } from "next/navigation";
import { detectOrigin } from "./env.js";
export async function signIn(provider, options, config) {
    const headers = new Headers(nextHeaders());
    headers.set("Content-Type", "application/x-www-form-urlencoded");
    const url = `${detectOrigin(headers)}signin/${provider}`;
    const callbackUrl = options?.redirectTo ?? headers.get("Referer") ?? "/";
    const body = new URLSearchParams({ callbackUrl });
    const req = new Request(url, { method: "POST", headers, body });
    const res = await Auth(req, { ...config, raw, skipCSRFCheck });
    for (const c of res?.cookies ?? [])
        cookies().set(c.name, c.value, c.options);
    if (options?.redirect)
        return redirect(res.redirect);
    return res.redirect;
}
export async function signOut(options, config) {
    const headers = new Headers(nextHeaders());
    headers.set("Content-Type", "application/x-www-form-urlencoded");
    const url = `${detectOrigin(headers)}signout`;
    const callbackUrl = options?.redirectTo ?? headers.get("Referer") ?? "/";
    const body = new URLSearchParams({ callbackUrl });
    const req = new Request(url, { method: "POST", headers, body });
    const res = await Auth(req, { ...config, raw, skipCSRFCheck });
    for (const c of res?.cookies ?? [])
        cookies().set(c.name, c.value, c.options);
    if (options?.redirect)
        return redirect(res.redirect);
    return res.redirect;
}
export async function update(data, config) {
    const headers = new Headers(nextHeaders());
    headers.set("Content-Type", "application/json");
    const url = `${detectOrigin(headers)}session`;
    const body = JSON.stringify({ data });
    const req = new Request(url, { method: "POST", headers, body });
    const res = await Auth(req, { ...config, raw, skipCSRFCheck });
    for (const c of res?.cookies ?? [])
        cookies().set(c.name, c.value, c.options);
    return res.body;
}
